@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -19,7 +19,7 @@ public:
     void removeFilesTriggered(const Utils::FilePaths &filesToRemove);
 
 private:
-    RestoreResult fromMap(const QVariantMap &map, QString *errorMessage) final;
+    RestoreResult fromMap(const Utils::Store &map, QString *errorMessage) final;
     ProjectExplorer::DeploymentKnowledge deploymentKnowledge() const final;
     void configureAsExampleProject(ProjectExplorer::Kit *kit) override;
 };
